@@ -15,13 +15,11 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkclist.h>
-#include <gtk/gtkcheckmenuitem.h>
+#include <gtk/gtk.h>
 
 #include "stats/links.h"
 
-guint update_info_windows (void);
+gboolean update_info_windows(gpointer dummy);
 void node_protocols_window_create(const node_id_t * node_id);
 void link_info_window_create(const link_id_t * link_id);
 
