@@ -29,7 +29,6 @@
 #include <glib/gi18n.h>
 #include <popt.h>
 #include <gtk/gtk.h>
-#include <libgnomecanvas/libgnomecanvas.h>
 #include "appdata.h"
 #include "names/ip-cache.h"
 #include "main.h"
@@ -60,7 +59,7 @@ static void (*old_sighup_handler) (int);
  **************************************************************************/
 static void free_static_data(void);
 static void set_debug_level (void);
-static void log_handler (gchar * log_domain, GLogLevelFlags mask, 
+static void log_handler (gchar * log_domain, GLogLevelFlags mask,
                          const gchar * message, gpointer user_data);
 static GPtrArray *parse_position_file(const gchar *path);
 
@@ -235,7 +234,7 @@ int main (int argc, char *argv[])
     }
   else
       g_message("Invalid minimum delay %ld, ignored", midelay);
-  
+
   if (madelay >= 0 && madelay <= G_MAXLONG)
     {
       if (madelay < appdata.min_delay)
@@ -254,42 +253,40 @@ int main (int argc, char *argv[])
   if (position_file_path)
     appdata.column_patterns = parse_position_file(position_file_path);
 
-  /* Glade */
-  glade_init ();
-  glade_require("gnome");
-  if (!appdata_init_glade(cl_glade_file))
+  /* GtkBuilder */
+  if (!appdata_init_builder(cl_glade_file))
     return 1;
 
   /* prepare decoders */
   services_init();
 
   /* Sets controls to the values of variables and connects signals */
-  init_diagram (appdata.xml);
+  init_diagram(appdata.xml);
 
   if (!pref.show_statusbar)
     {
       widget = GTK_WIDGET(appdata.statusbar);
       gtk_widget_hide(widget);
 
-      widget = glade_xml_get_widget(appdata.xml, "status_bar_check");
+      widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "status_bar_check"));
       gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(widget), FALSE);
     }
 
   if (!pref.show_toolbar)
     {
-      widget = glade_xml_get_widget(appdata.xml, "handlebox_toolbar");
+      widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "handlebox_toolbar"));
       gtk_widget_hide(widget);
 
-      widget = glade_xml_get_widget(appdata.xml, "toolbar_check");
+      widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "toolbar_check"));
       gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(widget), FALSE);
     }
 
   if (!pref.show_legend)
     {
-      widget = glade_xml_get_widget(appdata.xml, "handlebox_legend");
+      widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "handlebox_legend"));
       gtk_widget_hide(widget);
 
-      widget = glade_xml_get_widget(appdata.xml, "legend_check");
+      widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "legend_check"));
       gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(widget), FALSE);
     }
 
@@ -297,19 +294,13 @@ int main (int argc, char *argv[])
 
   install_handlers();
 
-  /* With this we force an update of the diagram every x ms 
+  /* With this we force an update of the diagram every x ms
    * Data in the diagram is updated, and then the canvas redraws itself when
    * the gtk loop is idle. If the CPU can't handle the set refresh_period,
    * then it will just do a best effort */
-
-  widget = glade_xml_get_widget (appdata.xml, "canvas1");
-  destroying_idle (widget);
-
-  /* Enable anti-aliasing */
-  GNOME_CANVAS(widget)->aa = TRUE;
-
+  diagram_timeout_changed();
   /* This other timeout makes sure that the info windows are updated */
-  g_timeout_add (500, (GtkFunction) update_info_windows, NULL);
+  g_timeout_add(500, update_info_windows, NULL);
 
   if (pref.name_res && dns_open())
     g_warning(_("DNS resolver initialization failed"));
@@ -421,7 +412,7 @@ static GPtrArray *parse_position_file(const gchar *path)
   return colpos;
 }
 
-/* releases all static and cached data. Called just before exiting. Obviously 
+/* releases all static and cached data. Called just before exiting. Obviously
  * it's not stricly needed, since the memory will be returned to the OS anyway,
  * but makes finding memory leaks much easier. */
 static void free_static_data(void)
@@ -456,7 +447,7 @@ set_debug_level (void)
   // unfortunately it can be controlled only by environment vars ...
   // Silly change!
   g_setenv("G_MESSAGES_DEBUG", "all", TRUE);
-        
+
   if (quiet)
     appdata.debug_mask = 0;
 
@@ -481,7 +472,7 @@ log_handler (gchar * log_domain,
 /* installs signal handlers */
 static void install_handlers(void)
 {
-  /* 
+  /*
    * Signal handling
    * Catch SIGINT and SIGTERM and, if we get either of them, clean up
    * and exit.
@@ -507,9 +498,9 @@ static void install_handlers(void)
  */
 void cleanup(int signum)
 {
-  cleanup_capture ();
+  cleanup_capture();
   free_static_data();
-  gtk_exit (0);
+  exit(0);
 }
 
 /* activates a flag requesting an xml dump */
