@@ -48,8 +48,8 @@ static void nodes_table_update(GtkWidget *window);
 
 void nodes_wnd_show(void)
 {
-  nodes_wnd = glade_xml_get_widget (appdata.xml, "nodes_wnd");
-  nodes_check = GTK_CHECK_MENU_ITEM(glade_xml_get_widget (appdata.xml, "nodes_check"));
+  nodes_wnd = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "nodes_wnd"));
+  nodes_check = GTK_CHECK_MENU_ITEM(gtk_builder_get_object(appdata.xml, "nodes_check"));
 
   if (DEBUG_ENABLED)
     {
@@ -58,11 +58,11 @@ void nodes_wnd_show(void)
       g_free(nodemsg);
     }
   
-  if (!nodes_wnd || GTK_WIDGET_VISIBLE (nodes_wnd))
+  if (!nodes_wnd || gtk_widget_get_visible(nodes_wnd))
     return;
 
-  gtk_widget_show (nodes_wnd);
-  gdk_window_raise (nodes_wnd->window);
+  gtk_widget_show(nodes_wnd);
+  gdk_window_raise(gtk_widget_get_window(nodes_wnd));
   if (nodes_check && !gtk_check_menu_item_get_active(nodes_check))
     gtk_check_menu_item_set_active(nodes_check, TRUE);
   nodes_wnd_update();
@@ -70,7 +70,7 @@ void nodes_wnd_show(void)
 
 void nodes_wnd_hide(void)
 {
-  if (!nodes_wnd || !GTK_WIDGET_VISIBLE (nodes_wnd))
+  if (!nodes_wnd || !gtk_widget_get_visible(nodes_wnd))
     return;
 
   gtk_widget_hide (nodes_wnd);
@@ -81,7 +81,7 @@ void nodes_wnd_hide(void)
 
 void nodes_wnd_update(void)
 {
-  if (!nodes_wnd || !GTK_WIDGET_VISIBLE (nodes_wnd))
+  if (!nodes_wnd || !gtk_widget_get_visible(nodes_wnd))
     return;
 
   nodes_table_update(nodes_wnd);
@@ -197,7 +197,7 @@ static GtkListStore *nodes_table_create(GtkWidget *window)
   gv = retrieve_treeview(window);
   if (!gv)
     {
-      gv = GTK_TREE_VIEW (glade_xml_get_widget (appdata.xml, "nodes_table"));
+      gv = GTK_TREE_VIEW (gtk_builder_get_object (appdata.xml, "nodes_table"));
       if (!gv)
         {
           g_critical("can't find nodes_table");
@@ -412,10 +412,10 @@ void on_nodes_check_toggled(GtkCheckMenuItem *checkmenuitem,  gpointer data)
 
 void on_nodes_toolbar_button_clicked(void)
 {
-  GtkWidget *nodes_check = glade_xml_get_widget (appdata.xml, "nodes_check");
+  GtkWidget *nodes_check = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "nodes_check"));
   if (!nodes_check)
     return;
-  gtk_menu_item_activate (GTK_MENU_ITEM (nodes_check));
+  gtk_menu_item_activate(GTK_MENU_ITEM (nodes_check));
 }
 
 /* double click on row */
