@@ -1,7 +1,7 @@
 /* EtherApe
  * Copyright (C) 2001 Juan Toledo
  * Copyright (C) 2011 Riccardo Ghetta
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -20,6 +20,8 @@
 #include <config.h>
 #endif
 
+#include <gtk/gtk.h>
+
 #include "pref_dialog.h"
 #include "preferences.h"
 #include "diagram.h"
@@ -33,14 +35,14 @@
 
 static void color_list_to_pref (void);
 static void pref_to_color_list (void);
-static void on_stack_level_changed(GtkComboBox * combo, gpointer data);
+static void on_stack_level_changed(GtkWidget * combo, gpointer data);
 static void on_size_variable_changed(GtkComboBox * combo, gpointer data);
 static void on_size_mode_changed(GtkComboBox * combo, gpointer data);
 static void on_text_color_changed(GtkColorButton * wdg, gpointer data);
 static void on_text_font_changed(GtkFontButton * wdg, gpointer data);
-static void on_filter_entry_changed(GtkComboBoxEntry * cbox, gpointer user_data);
-static void on_center_node_changed(GtkComboBoxEntry * cbox, gpointer user_data);
-static void cbox_add_select(GtkComboBoxEntry *cbox, const gchar *str);
+static void on_filter_entry_changed(GtkComboBox * cbox, gpointer user_data);
+static void on_center_node_changed(GtkComboBox * cbox, gpointer user_data);
+static void cbox_add_select(GtkComboBox *cbox, const gchar *str);
 
 
 static gboolean colors_changed = FALSE;
@@ -53,11 +55,11 @@ confirm_changes(void)
 {
   GtkWidget *widget = NULL;
 
-  widget = glade_xml_get_widget (appdata.xml, "filter_combo");
-  on_filter_entry_changed (GTK_COMBO_BOX_ENTRY(widget), NULL);
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "filter_combo"));
+  on_filter_entry_changed(GTK_COMBO_BOX(widget), NULL);
 
-  widget = glade_xml_get_widget (appdata.xml, "center_combo");
-  on_center_node_changed (GTK_COMBO_BOX_ENTRY(widget), NULL);
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "center_combo"));
+  on_center_node_changed(GTK_COMBO_BOX(widget), NULL);
 
   if (colors_changed)
     {
@@ -79,77 +81,76 @@ hide_pref_dialog(void)
   gtk_widget_hide (diag_pref);
 }
 
-void
-initialize_pref_controls(void)
+void initialize_pref_controls(void)
 {
   GtkWidget *widget;
   GtkSpinButton *spin;
-  GdkColor color;
+  GdkRGBA color;
   GtkTreeModel *model;
 
-  diag_pref = glade_xml_get_widget (appdata.xml, "diag_pref");
+  diag_pref = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "diag_pref"));
 
   /* Updates controls from values of variables */
-  widget = glade_xml_get_widget (appdata.xml, "node_radius_slider");
-  gtk_adjustment_set_value (GTK_RANGE (widget)->adjustment,
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "node_radius_slider"));
+  gtk_adjustment_set_value(gtk_range_get_adjustment(GTK_RANGE(widget)),
 			    log (pref.node_radius_multiplier) / log (10));
-  g_signal_emit_by_name (G_OBJECT (GTK_RANGE (widget)->adjustment),
+  g_signal_emit_by_name (G_OBJECT(gtk_range_get_adjustment(GTK_RANGE(widget))),
 			 "changed");
-  widget = glade_xml_get_widget (appdata.xml, "link_width_slider");
-  gtk_adjustment_set_value (GTK_RANGE (widget)->adjustment,
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "link_width_slider"));
+  gtk_adjustment_set_value(gtk_range_get_adjustment(GTK_RANGE(widget)),
 			    pref.link_node_ratio);
-  g_signal_emit_by_name (GTK_OBJECT (GTK_RANGE (widget)->adjustment),
+  g_signal_emit_by_name(G_OBJECT(gtk_range_get_adjustment(GTK_RANGE(widget))),
 			 "changed");
-  widget = glade_xml_get_widget (appdata.xml, "inner_ring_scale_slider");
-  gtk_adjustment_set_value (GTK_RANGE (widget)->adjustment,
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "inner_ring_scale_slider"));
+  gtk_adjustment_set_value(gtk_range_get_adjustment(GTK_RANGE(widget)),
                             pref.inner_ring_scale);
-  g_signal_emit_by_name (GTK_OBJECT (GTK_RANGE (widget)->adjustment),
+  g_signal_emit_by_name(G_OBJECT(gtk_range_get_adjustment(GTK_RANGE(widget))),
 			 "changed");
-  spin = GTK_SPIN_BUTTON (glade_xml_get_widget (appdata.xml, "averaging_spin"));
+  spin = GTK_SPIN_BUTTON (gtk_builder_get_object (appdata.xml, "averaging_spin"));
   gtk_spin_button_set_value (spin, pref.averaging_time);
-  spin = GTK_SPIN_BUTTON (glade_xml_get_widget (appdata.xml, "refresh_spin"));
+  spin = GTK_SPIN_BUTTON (gtk_builder_get_object (appdata.xml, "refresh_spin"));
   gtk_spin_button_set_value (spin, pref.refresh_period);
-  spin = GTK_SPIN_BUTTON (glade_xml_get_widget (appdata.xml, "node_to_spin"));
+  spin = GTK_SPIN_BUTTON (gtk_builder_get_object (appdata.xml, "node_to_spin"));
   gtk_spin_button_set_value (spin, pref.node_timeout_time/MILLI);
-  spin = GTK_SPIN_BUTTON (glade_xml_get_widget (appdata.xml, "gui_node_to_spin"));
+  spin = GTK_SPIN_BUTTON (gtk_builder_get_object (appdata.xml, "gui_node_to_spin"));
   gtk_spin_button_set_value (spin, pref.gui_node_timeout_time/MILLI);
-  spin = GTK_SPIN_BUTTON (glade_xml_get_widget (appdata.xml, "proto_node_to_spin"));
+  spin = GTK_SPIN_BUTTON (gtk_builder_get_object (appdata.xml, "proto_node_to_spin"));
   gtk_spin_button_set_value (spin, pref.proto_node_timeout_time/MILLI);
 
-  spin = GTK_SPIN_BUTTON (glade_xml_get_widget (appdata.xml, "link_to_spin"));
+  spin = GTK_SPIN_BUTTON (gtk_builder_get_object (appdata.xml, "link_to_spin"));
   gtk_spin_button_set_value (spin, pref.link_timeout_time/MILLI);
-  spin = GTK_SPIN_BUTTON (glade_xml_get_widget (appdata.xml, "gui_link_to_spin"));
+  spin = GTK_SPIN_BUTTON (gtk_builder_get_object (appdata.xml, "gui_link_to_spin"));
   gtk_spin_button_set_value (spin, pref.gui_link_timeout_time/MILLI);
-  spin = GTK_SPIN_BUTTON (glade_xml_get_widget (appdata.xml, "proto_link_to_spin"));
+  spin = GTK_SPIN_BUTTON (gtk_builder_get_object (appdata.xml, "proto_link_to_spin"));
   gtk_spin_button_set_value (spin, pref.proto_link_timeout_time/MILLI);
 
-  spin = GTK_SPIN_BUTTON (glade_xml_get_widget (appdata.xml, "proto_to_spin"));
+  spin = GTK_SPIN_BUTTON (gtk_builder_get_object (appdata.xml, "proto_to_spin"));
   gtk_spin_button_set_value (spin, pref.proto_timeout_time/MILLI);
 
-  widget = glade_xml_get_widget (appdata.xml, "diagram_only_toggle");
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "diagram_only_toggle"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget),
 				pref.diagram_only);
-  widget = glade_xml_get_widget (appdata.xml, "group_unk_check");
+  widget = GTK_WIDGET(gtk_builder_get_object (appdata.xml, "group_unk_check"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), pref.group_unk);
-  widget = glade_xml_get_widget (appdata.xml, "name_res_check");
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "name_res_check"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), pref.name_res);
-  widget = glade_xml_get_widget (appdata.xml, "stack_level");
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "stack_level"));
   gtk_combo_box_set_active(GTK_COMBO_BOX(widget), pref.stack_level);
-  widget = glade_xml_get_widget (appdata.xml, "size_variable");
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "size_variable"));
   gtk_combo_box_set_active(GTK_COMBO_BOX(widget), pref.node_size_variable);
-  widget = glade_xml_get_widget (appdata.xml, "size_mode");
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "size_mode"));
   gtk_combo_box_set_active(GTK_COMBO_BOX(widget), pref.size_mode);
-  widget = glade_xml_get_widget (appdata.xml, "text_font");
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "text_font"));
   gtk_font_button_set_font_name(GTK_FONT_BUTTON(widget), pref.fontname);
-  widget = glade_xml_get_widget (appdata.xml, "text_color");
-  if (!gdk_color_parse(pref.text_color, &color))
-    gdk_color_parse("#ffff00", &color);
-  gtk_color_button_set_color(GTK_COLOR_BUTTON(widget), &color);
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "text_color"));
+  if (!gdk_rgba_parse(&color, pref.text_color))
+    gdk_rgba_parse(&color, "#ffff00");
+  gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(widget), &color);
 
-  widget = glade_xml_get_widget (appdata.xml, "pcap_stats_pos");
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "pcap_stats_pos"));
   gtk_combo_box_set_active(GTK_COMBO_BOX(widget), pref.pcap_stats_pos);
 
-  widget = glade_xml_get_widget (appdata.xml, "filter_combo");
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "filter_combo"));
   model = gtk_combo_box_get_model(GTK_COMBO_BOX(widget));
   if (!model)
     {
@@ -158,7 +159,7 @@ initialize_pref_controls(void)
       gtk_combo_box_set_model(GTK_COMBO_BOX(widget), GTK_TREE_MODEL(list_store));
     }
 
-  widget = glade_xml_get_widget (appdata.xml, "center_combo");
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "center_combo"));
   model = gtk_combo_box_get_model(GTK_COMBO_BOX(widget));
   if (!model)
     {
@@ -169,208 +170,184 @@ initialize_pref_controls(void)
 
   pref_to_color_list();		/* Updates the color preferences table with pref.colors */
 
-  widget = glade_xml_get_widget(appdata.xml, "bck_image_enabled");
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "bck_image_enabled"));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget), pref.bck_image_enabled);
-  gtk_widget_set_sensitive(glade_xml_get_widget(appdata.xml, "bck_image_open"), pref.bck_image_enabled);
+  gtk_widget_set_sensitive(GTK_WIDGET(gtk_builder_get_object(appdata.xml, "bck_image_open")), 
+                           pref.bck_image_enabled);
 
   if (pref.bck_image_path && *pref.bck_image_path) {
-    widget = glade_xml_get_widget(appdata.xml, "bck_image_open");
+    widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "bck_image_open"));
     gtk_file_chooser_select_filename(GTK_FILE_CHOOSER(widget), pref.bck_image_path);
   }
 
   /* Connects signals */
-  widget = glade_xml_get_widget (appdata.xml, "diag_pref");
+  widget = GTK_WIDGET(gtk_builder_get_object (appdata.xml, "diag_pref"));
+  g_signal_connect(G_OBJECT (widget),
+		   "delete_event",
+		   G_CALLBACK(on_cancel_pref_button_clicked ), NULL);
+  widget = GTK_WIDGET(gtk_builder_get_object (appdata.xml, "node_radius_slider"));
+  g_signal_connect(G_OBJECT(gtk_range_get_adjustment(GTK_RANGE(widget))),
+		   "value_changed",
+		   G_CALLBACK(on_node_radius_slider_adjustment_changed), NULL);
+  widget = GTK_WIDGET(gtk_builder_get_object (appdata.xml, "link_width_slider"));
+  g_signal_connect(G_OBJECT(gtk_range_get_adjustment(GTK_RANGE(widget))),
+		   "value_changed",
+		   G_CALLBACK(on_link_width_slider_adjustment_changed), NULL);
+  widget = GTK_WIDGET(gtk_builder_get_object (appdata.xml, "inner_ring_scale_slider"));
+  g_signal_connect(G_OBJECT(gtk_range_get_adjustment(GTK_RANGE(widget))),
+		    "value_changed",
+		    G_CALLBACK(on_inner_ring_scale_slider_adjustment_changed), NULL);
+  widget = GTK_WIDGET(gtk_builder_get_object (appdata.xml, "averaging_spin"));
+  g_signal_connect (G_OBJECT(gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(widget))),
+		    "value_changed",
+		    G_CALLBACK(on_averaging_spin_adjustment_changed), NULL);
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "refresh_spin"));
+  g_signal_connect (G_OBJECT(gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(widget))),
+		    "value_changed",
+		    G_CALLBACK(on_refresh_spin_adjustment_changed),
+		    canvas_widget());
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "node_to_spin"));
+  g_signal_connect (G_OBJECT(gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(widget))),
+		    "value_changed",
+		    G_CALLBACK(on_node_to_spin_adjustment_changed), NULL);
+  widget = GTK_WIDGET(gtk_builder_get_object (appdata.xml, "gui_node_to_spin"));
+  g_signal_connect (G_OBJECT(gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(widget))),
+		    "value_changed",
+		    G_CALLBACK(on_gui_node_to_spin_adjustment_changed), NULL);
+  widget = GTK_WIDGET(gtk_builder_get_object (appdata.xml, "proto_node_to_spin"));
+  g_signal_connect (G_OBJECT(gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(widget))),
+		    "value_changed",
+		    G_CALLBACK(on_proto_node_to_spin_adjustment_changed), NULL);
+  widget = GTK_WIDGET(gtk_builder_get_object (appdata.xml, "link_to_spin"));
+  g_signal_connect (G_OBJECT(gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(widget))),
+		    "value_changed",
+		    G_CALLBACK(on_link_to_spin_adjustment_changed), NULL);
+  widget = GTK_WIDGET(gtk_builder_get_object (appdata.xml, "gui_link_to_spin"));
+  g_signal_connect (G_OBJECT(gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(widget))),
+		    "value_changed",
+		    G_CALLBACK(on_gui_link_to_spin_adjustment_changed), NULL);
+  widget = GTK_WIDGET(gtk_builder_get_object (appdata.xml, "proto_link_to_spin"));
+  g_signal_connect (G_OBJECT(gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(widget))),
+		    "value_changed",
+		    G_CALLBACK(on_proto_link_to_spin_adjustment_changed), NULL);
+  widget = GTK_WIDGET(gtk_builder_get_object (appdata.xml, "proto_to_spin"));
+  g_signal_connect (G_OBJECT(gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(widget))),
+		    "value_changed",
+		    G_CALLBACK(on_proto_to_spin_adjustment_changed), NULL);
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "stack_level"));
   g_signal_connect (G_OBJECT (widget),
-		    "delete_event",
-		    GTK_SIGNAL_FUNC
-		    (on_cancel_pref_button_clicked ), NULL);
-  widget = glade_xml_get_widget (appdata.xml, "node_radius_slider");
-  g_signal_connect (G_OBJECT (GTK_RANGE (widget)->adjustment),
-		    "value_changed",
-		    GTK_SIGNAL_FUNC
-		    (on_node_radius_slider_adjustment_changed), NULL);
-  widget = glade_xml_get_widget (appdata.xml, "link_width_slider");
-  g_signal_connect (G_OBJECT (GTK_RANGE (widget)->adjustment),
-		    "value_changed",
-		    GTK_SIGNAL_FUNC
-		    (on_link_width_slider_adjustment_changed), NULL);
-  widget = glade_xml_get_widget (appdata.xml, "inner_ring_scale_slider");
-  g_signal_connect (G_OBJECT (GTK_RANGE (widget)->adjustment),
-		    "value_changed",
-		    GTK_SIGNAL_FUNC
-		    (on_inner_ring_scale_slider_adjustment_changed), NULL);
-  widget = glade_xml_get_widget (appdata.xml, "averaging_spin");
-  g_signal_connect (G_OBJECT (GTK_SPIN_BUTTON (widget)->adjustment),
-		    "value_changed",
-		    GTK_SIGNAL_FUNC
-		    (on_averaging_spin_adjustment_changed), NULL);
-  widget = glade_xml_get_widget (appdata.xml, "refresh_spin");
-  g_signal_connect (G_OBJECT (GTK_SPIN_BUTTON (widget)->adjustment),
-		    "value_changed",
-		    GTK_SIGNAL_FUNC
-		    (on_refresh_spin_adjustment_changed),
-		    glade_xml_get_widget (appdata.xml, "canvas1"));
-  widget = glade_xml_get_widget (appdata.xml, "node_to_spin");
-  g_signal_connect (G_OBJECT (GTK_SPIN_BUTTON (widget)->adjustment),
-		    "value_changed",
-		    GTK_SIGNAL_FUNC
-		    (on_node_to_spin_adjustment_changed), NULL);
-  widget = glade_xml_get_widget (appdata.xml, "gui_node_to_spin");
-  g_signal_connect (G_OBJECT (GTK_SPIN_BUTTON (widget)->adjustment),
-		    "value_changed",
-		    GTK_SIGNAL_FUNC
-		    (on_gui_node_to_spin_adjustment_changed), NULL);
-  widget = glade_xml_get_widget (appdata.xml, "proto_node_to_spin");
-  g_signal_connect (G_OBJECT (GTK_SPIN_BUTTON (widget)->adjustment),
-		    "value_changed",
-		    GTK_SIGNAL_FUNC
-		    (on_proto_node_to_spin_adjustment_changed), NULL);
-  widget = glade_xml_get_widget (appdata.xml, "link_to_spin");
-  g_signal_connect (G_OBJECT (GTK_SPIN_BUTTON (widget)->adjustment),
-		    "value_changed",
-		    GTK_SIGNAL_FUNC
-		    (on_link_to_spin_adjustment_changed), NULL);
-  widget = glade_xml_get_widget (appdata.xml, "gui_link_to_spin");
-  g_signal_connect (G_OBJECT (GTK_SPIN_BUTTON (widget)->adjustment),
-		    "value_changed",
-		    GTK_SIGNAL_FUNC
-		    (on_gui_link_to_spin_adjustment_changed), NULL);
-  widget = glade_xml_get_widget (appdata.xml, "proto_link_to_spin");
-  g_signal_connect (G_OBJECT (GTK_SPIN_BUTTON (widget)->adjustment),
-		    "value_changed",
-		    GTK_SIGNAL_FUNC
-		    (on_proto_link_to_spin_adjustment_changed), NULL);
-  widget = glade_xml_get_widget (appdata.xml, "proto_to_spin");
-  g_signal_connect (G_OBJECT (GTK_SPIN_BUTTON (widget)->adjustment),
-		    "value_changed",
-		    GTK_SIGNAL_FUNC
-		    (on_proto_to_spin_adjustment_changed), NULL);
-  widget = glade_xml_get_widget (appdata.xml, "stack_level");
-  g_signal_connect (G_OBJECT (widget), 
                     "changed",
-		    GTK_SIGNAL_FUNC (on_stack_level_changed), NULL);
-  widget = glade_xml_get_widget (appdata.xml, "size_variable");
-  g_signal_connect (G_OBJECT (widget), 
+		    G_CALLBACK(on_stack_level_changed), NULL);
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "size_variable"));
+  g_signal_connect (G_OBJECT (widget),
                     "changed",
-		    GTK_SIGNAL_FUNC (on_size_variable_changed), NULL);
-  widget = glade_xml_get_widget (appdata.xml, "size_mode");
-  g_signal_connect (G_OBJECT (widget), 
+		    G_CALLBACK(on_size_variable_changed), NULL);
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "size_mode"));
+  g_signal_connect (G_OBJECT (widget),
                     "changed",
-		    GTK_SIGNAL_FUNC (on_size_mode_changed), NULL);
-  widget = glade_xml_get_widget (appdata.xml, "text_font");
-  g_signal_connect (G_OBJECT (widget), 
+		    G_CALLBACK(on_size_mode_changed), NULL);
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "text_font"));
+  g_signal_connect (G_OBJECT (widget),
                     "font_set",
-		    GTK_SIGNAL_FUNC (on_text_font_changed), NULL);
-  widget = glade_xml_get_widget (appdata.xml, "text_color");
-  g_signal_connect (G_OBJECT (widget), 
+		    G_CALLBACK(on_text_font_changed), NULL);
+  widget = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "text_color"));
+  g_signal_connect (G_OBJECT (widget),
                     "color_set",
-		    GTK_SIGNAL_FUNC (on_text_color_changed), NULL);
+		    G_CALLBACK(on_text_color_changed), NULL);
 }
 
-void
-on_preferences1_activate (GtkMenuItem * menuitem, gpointer user_data)
+void on_preferences1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-  GtkComboBoxEntry *cbox;
+  GtkComboBox *cbox;
 
   /* saves current prefs to a temporary */
   copy_config(&tmp_pref, &pref);
 
   initialize_pref_controls();
 
-  cbox = GTK_COMBO_BOX_ENTRY(glade_xml_get_widget (appdata.xml, "filter_combo"));
+  cbox = GTK_COMBO_BOX(gtk_builder_get_object(appdata.xml, "filter_combo"));
   cbox_add_select(cbox, pref.filter);
 
-  cbox = GTK_COMBO_BOX_ENTRY(glade_xml_get_widget (appdata.xml, "center_combo"));
+  cbox = GTK_COMBO_BOX(gtk_builder_get_object(appdata.xml, "center_combo"));
   cbox_add_select(cbox, pref.centered_nodes);
 
-  gtk_widget_show (diag_pref);
-  gdk_window_raise (diag_pref->window);
+  gtk_widget_show(diag_pref);
+  gdk_window_raise(gtk_widget_get_window(diag_pref));
 }
 
-void
-on_node_radius_slider_adjustment_changed (GtkAdjustment * adj)
+void on_node_radius_slider_adjustment_changed(GtkAdjustment * adj)
 {
-
-  pref.node_radius_multiplier = exp ((double) adj->value * log (10));
-  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,
-	 _("Adjustment value: %g. Radius multiplier %g"),
-	 adj->value, pref.node_radius_multiplier);
+  double value = gtk_adjustment_get_value(adj);
+  pref.node_radius_multiplier = exp(value * log(10));
+  g_log(G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,
+	_("Adjustment value: %g. Radius multiplier %g"),
+	value, pref.node_radius_multiplier);
 
 }
 
-void
-on_link_width_slider_adjustment_changed (GtkAdjustment * adj)
+void on_link_width_slider_adjustment_changed(GtkAdjustment * adj)
 {
-
-  pref.link_node_ratio = adj->value;
-  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,
-	 _("Adjustment value: %g. Link-node ratio %g"),
-	 adj->value, pref.link_node_ratio);
+  double value = gtk_adjustment_get_value(adj);
+  pref.link_node_ratio = value;
+  g_log(G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,
+	_("Adjustment value: %g. Link-node ratio %g"),
+	value, pref.link_node_ratio);
 
 }
 
-void
-on_inner_ring_scale_slider_adjustment_changed (GtkAdjustment * adj)
+void on_inner_ring_scale_slider_adjustment_changed(GtkAdjustment * adj)
 {
-  pref.inner_ring_scale = adj->value;
-  g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,
-         _("Adjustment value: %g. Inner ring scale %g"),
-         adj->value, pref.inner_ring_scale);
+  double value = gtk_adjustment_get_value(adj);
+  pref.inner_ring_scale = value;
+  g_log(G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,
+        _("Adjustment value: %g. Inner ring scale %g"),
+        value, pref.inner_ring_scale);
   ask_reposition(FALSE);
 }
 
-void
-on_averaging_spin_adjustment_changed (GtkAdjustment * adj)
+void on_averaging_spin_adjustment_changed (GtkAdjustment * adj)
 {
-  pref.averaging_time = adj->value;	/* Control and value in ms */
+  pref.averaging_time = gtk_adjustment_get_value(adj);	/* Control and value in ms */
 }
 
-void
-on_refresh_spin_adjustment_changed (GtkAdjustment * adj, GtkWidget * canvas)
+void on_refresh_spin_adjustment_changed (GtkAdjustment * adj, GtkWidget * canvas)
 {
-  change_refresh_period(adj->value);
+  change_refresh_period(gtk_adjustment_get_value(adj));
 }
 
-void
-on_node_to_spin_adjustment_changed (GtkAdjustment * adj)
+void on_node_to_spin_adjustment_changed (GtkAdjustment * adj)
 {
-  pref.node_timeout_time = adj->value*MILLI;	/* value in ms */
-}				/* on_node_to_spin_adjustment_changed */
-
-void
-on_gui_node_to_spin_adjustment_changed (GtkAdjustment * adj)
-{
-  pref.gui_node_timeout_time = adj->value*MILLI;	/* value in ms */
+  pref.node_timeout_time = gtk_adjustment_get_value(adj)*MILLI;	/* value in ms */
 }
 
-void
-on_proto_node_to_spin_adjustment_changed (GtkAdjustment * adj)
+void on_gui_node_to_spin_adjustment_changed (GtkAdjustment * adj)
 {
-  pref.proto_node_timeout_time = adj->value*MILLI;	/* value in ms */
+  pref.gui_node_timeout_time = gtk_adjustment_get_value(adj)*MILLI;	/* value in ms */
 }
 
-void
-on_link_to_spin_adjustment_changed (GtkAdjustment * adj)
+void on_proto_node_to_spin_adjustment_changed (GtkAdjustment * adj)
 {
-  pref.link_timeout_time = adj->value*MILLI;	/* value in ms */
+  pref.proto_node_timeout_time = gtk_adjustment_get_value(adj)*MILLI;	/* value in ms */
 }
 
-void
-on_gui_link_to_spin_adjustment_changed (GtkAdjustment * adj)
+void on_link_to_spin_adjustment_changed (GtkAdjustment * adj)
 {
-  pref.gui_link_timeout_time = adj->value*MILLI;	/* value in ms */
+  pref.link_timeout_time = gtk_adjustment_get_value(adj)*MILLI;	/* value in ms */
 }
 
-void
-on_proto_link_to_spin_adjustment_changed (GtkAdjustment * adj)
+void on_gui_link_to_spin_adjustment_changed (GtkAdjustment * adj)
 {
-  pref.proto_link_timeout_time = adj->value*MILLI;	/* value in ms */
+  pref.gui_link_timeout_time = gtk_adjustment_get_value(adj)*MILLI;	/* value in ms */
 }
 
-void
-on_proto_to_spin_adjustment_changed (GtkAdjustment * adj)
+void on_proto_link_to_spin_adjustment_changed (GtkAdjustment * adj)
 {
-  pref.proto_timeout_time = adj->value*MILLI;	/* value in ms */
+  pref.proto_link_timeout_time = gtk_adjustment_get_value(adj)*MILLI;	/* value in ms */
+}
+
+void on_proto_to_spin_adjustment_changed (GtkAdjustment * adj)
+{
+  pref.proto_timeout_time = gtk_adjustment_get_value(adj)*MILLI;	/* value in ms */
 }
 
 static void on_size_mode_changed(GtkComboBox * combo, gpointer data)
@@ -387,9 +364,9 @@ static void on_size_variable_changed(GtkComboBox * combo, gpointer data)
   pref.node_size_variable = (node_size_variable_t)gtk_combo_box_get_active (combo);
 }
 
-static void on_stack_level_changed(GtkComboBox * combo, gpointer data)
+static void on_stack_level_changed(GtkWidget * combo, gpointer data)
 {
-  pref.stack_level = gtk_combo_box_get_active (combo);
+  pref.stack_level = gtk_combo_box_get_active(GTK_COMBO_BOX(combo));
   delete_gui_protocols();
 }
 
@@ -407,10 +384,10 @@ static void on_text_font_changed(GtkFontButton * wdg, gpointer data)
 
 static void on_text_color_changed(GtkColorButton * wdg, gpointer data)
 {
-  GdkColor new_color;
-  gtk_color_button_get_color(wdg, &new_color);
+  GdkRGBA new_color;
+  gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(wdg), &new_color);
   g_free(pref.text_color);
-  pref.text_color = gdk_color_to_string(&new_color);
+  pref.text_color = gdk_rgba_to_string(&new_color);
   ask_reposition(TRUE);
 }
 
@@ -432,8 +409,7 @@ on_group_unk_check_toggled (GtkToggleButton * togglebutton,
 /*
  * confirm changes
  */
-void
-on_ok_pref_button_clicked (GtkButton * button, gpointer user_data)
+void on_ok_pref_button_clicked (GtkWidget * button, gpointer user_data)
 {
   confirm_changes();
   hide_pref_dialog();
@@ -441,8 +417,7 @@ on_ok_pref_button_clicked (GtkButton * button, gpointer user_data)
 
 
 /* reset configuration to saved and close dialog */
-void
-on_cancel_pref_button_clicked (GtkButton * button, gpointer user_data)
+void on_cancel_pref_button_clicked (GtkWidget * button, gpointer user_data)
 {
   /* reset configuration to saved */
   copy_config(&pref, &tmp_pref);
@@ -457,8 +432,7 @@ on_cancel_pref_button_clicked (GtkButton * button, gpointer user_data)
   hide_pref_dialog();
 }				/* on_cancel_pref_button_clicked */
 
-void
-on_save_pref_button_clicked (GtkButton * button, gpointer user_data)
+void on_save_pref_button_clicked (GtkWidget * button, gpointer user_data)
 {
   confirm_changes();	/* to save we simulate confirmation */
   save_config(&pref);
@@ -467,30 +441,28 @@ on_save_pref_button_clicked (GtkButton * button, gpointer user_data)
 
 
 /* Makes a new filter */
-static void on_filter_entry_changed(GtkComboBoxEntry * cbox, gpointer user_data)
+static void on_filter_entry_changed(GtkComboBox *cbox, gpointer user_data)
 {
-  gchar *str;
+  const gchar *str;
   /* TODO should make sure that for each mode the filter is set up
    * correctly */
-  str = gtk_combo_box_get_active_text(GTK_COMBO_BOX(cbox));
+  str = gtk_entry_get_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(cbox))));
   if (pref.filter)
-    g_free (pref.filter);
-  pref.filter = g_strdup (str);
+    g_free(pref.filter);
+  pref.filter = g_strdup(str);
   /* TODO We should look at the error code from set_filter and pop
    * up a window accordingly */
   set_filter(pref.filter);
-  g_free (str);
   cbox_add_select(cbox, pref.filter);
 }				/* on_filter_entry_changed */
 
 /* Makes a new center node */
-static void on_center_node_changed(GtkComboBoxEntry * cbox, gpointer user_data)
+static void on_center_node_changed(GtkComboBox * cbox, gpointer user_data)
 {
-  gchar *str;
-  str = gtk_combo_box_get_active_text(GTK_COMBO_BOX(cbox));
+  const gchar *str;
+  str = gtk_entry_get_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(cbox))));
   g_free(pref.centered_nodes);
   pref.centered_nodes = g_strdup(str);
-  g_free(str);
   free_nodeset_spec_list(centered_node_speclist);
   centered_node_speclist = parse_nodeset_spec_list(pref.centered_nodes);
   cbox_add_select(cbox, pref.centered_nodes);
@@ -503,7 +475,7 @@ on_numeric_toggle_toggled (GtkToggleButton * togglebutton, gpointer user_data)
   pref.name_res = gtk_toggle_button_get_active (togglebutton);
 }				/* on_numeric_toggle_toggled */
 
-void 
+void
 on_background_image_path_selected (GtkFileChooserButton * filechooser, gpointer user_data)
 {
   pref.bck_image_path = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER (filechooser));
@@ -514,7 +486,7 @@ on_background_image_enable_toggled(GtkToggleButton *togglebutton, gpointer user_
 {
   gboolean on = gtk_toggle_button_get_active(togglebutton);
   pref.bck_image_enabled = on;
-  gtk_widget_set_sensitive(glade_xml_get_widget(appdata.xml, "bck_image_open"), on);
+  gtk_widget_set_sensitive(GTK_WIDGET(gtk_builder_get_object(appdata.xml, "bck_image_open")), on);
 }
 
 void on_pcap_stats_display_changed(GtkComboBox *combobox, gpointer user_data)
@@ -544,7 +516,7 @@ get_color_store (EATreePos * ep)
 {
   /* initializes the view ptr */
   ep->gs = NULL;
-  ep->gv = GTK_TREE_VIEW (glade_xml_get_widget (appdata.xml, "color_list"));
+  ep->gv = GTK_TREE_VIEW(gtk_builder_get_object (appdata.xml, "color_list"));
   if (!ep->gv)
     return FALSE;		/* error */
 
@@ -553,19 +525,19 @@ get_color_store (EATreePos * ep)
   if (ep->gs)
     return TRUE;		/* model already initialized, finished */
 
-  /* store not found, must be created  - it uses 3 values: 
+  /* store not found, must be created  - it uses 3 values:
      First the color string, then the gdk color, lastly the protocol */
-  ep->gs =
-    gtk_list_store_new (3, G_TYPE_STRING, GDK_TYPE_COLOR, G_TYPE_STRING);
-  gtk_tree_view_set_model (ep->gv, GTK_TREE_MODEL (ep->gs));
+  ep->gs = gtk_list_store_new(3, 
+                              G_TYPE_STRING, GDK_TYPE_RGBA, G_TYPE_STRING);
+  gtk_tree_view_set_model(ep->gv, GTK_TREE_MODEL(ep->gs));
 
-  /* the view columns and cell renderers must be also created ... 
+  /* the view columns and cell renderers must be also created ...
      Note: the bkg color is linked to the second column of store
    */
   gtk_tree_view_append_column (ep->gv,
 			       gtk_tree_view_column_new_with_attributes
 			       ("Color", gtk_cell_renderer_text_new (),
-				"text", 0, "background-gdk", 1, NULL));
+				"text", 0, "background-rgba", 1, NULL));
   gtk_tree_view_append_column (ep->gv,
 			       gtk_tree_view_column_new_with_attributes
 			       ("Protocol", gtk_cell_renderer_text_new (),
@@ -579,7 +551,7 @@ void
 on_color_add_button_clicked (GtkButton * button, gpointer user_data)
 {
   GtkWidget *dlg =
-    glade_xml_get_widget (appdata.xml, "colorselectiondialog");
+    GTK_WIDGET(gtk_builder_get_object(appdata.xml, "colorselectiondialog"));
   g_object_set_data( G_OBJECT(dlg), "isadd", GINT_TO_POINTER(TRUE));
   gtk_widget_show (dlg);
 }				/* on_color_add_button_clicked */
@@ -590,7 +562,7 @@ on_color_change_button_clicked (GtkButton * button, gpointer user_data)
   GtkTreePath *gpath;
   GtkTreeViewColumn *gcol;
   GtkTreeIter it;
-  GdkColor *gdk_color;
+  GdkRGBA *color;
   GtkColorSelectionDialog *dlg;
   GtkColorSelection *csel;
   EATreePos ep;
@@ -607,15 +579,15 @@ on_color_change_button_clicked (GtkButton * button, gpointer user_data)
   if (!gtk_tree_model_get_iter (GTK_TREE_MODEL (ep.gs), &it, gpath))
     return;
 
-  gtk_tree_model_get (GTK_TREE_MODEL (ep.gs), &it, 1, &gdk_color, -1);
+  gtk_tree_model_get (GTK_TREE_MODEL (ep.gs), &it, 1, &color, -1);
 
-  dlg = GTK_COLOR_SELECTION_DIALOG
-          (glade_xml_get_widget (appdata.xml, "colorselectiondialog"));
+  dlg = GTK_COLOR_SELECTION_DIALOG(
+          gtk_builder_get_object(appdata.xml, "colorselectiondialog"));
+
+  csel = GTK_COLOR_SELECTION(gtk_color_selection_dialog_get_color_selection(dlg));
+  gtk_color_selection_set_current_rgba(csel, color);
+  gtk_color_selection_set_previous_rgba(csel, color);
 
-  csel = GTK_COLOR_SELECTION(dlg->colorsel);
-  gtk_color_selection_set_current_color(csel, gdk_color);
-  gtk_color_selection_set_previous_color(csel, gdk_color);
-  
   g_object_set_data( G_OBJECT(dlg), "isadd", GINT_TO_POINTER(FALSE));
   gtk_widget_show (GTK_WIDGET(dlg));
 }				/* on_color_change_button_clicked */
@@ -660,7 +632,7 @@ void
 on_colordiag_ok_clicked (GtkButton * button, gpointer user_data)
 {
   GtkWidget *colorsel, *colorseldiag;
-  GdkColor gdk_color;
+  GdkRGBA color;
   GtkTreePath *gpath = NULL;
   GtkTreeViewColumn *gcol = NULL;
   GtkTreeIter it;
@@ -669,7 +641,7 @@ on_colordiag_ok_clicked (GtkButton * button, gpointer user_data)
   if (!get_color_store (&ep))
     return;
 
-  colorseldiag = glade_xml_get_widget (appdata.xml, "colorselectiondialog");
+  colorseldiag = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "colorselectiondialog"));
   isadd = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(colorseldiag), "isadd"));
 
   /* gets the row (path) at cursor */
@@ -690,27 +662,22 @@ on_colordiag_ok_clicked (GtkButton * button, gpointer user_data)
     }
   else
     {
-      if (!gpath || 
+      if (!gpath ||
           !gtk_tree_model_get_iter(GTK_TREE_MODEL (ep.gs), &it, gpath))
 	return;			/* path not found */
     }
 
   /* get the selected color */
-  colorsel = GTK_COLOR_SELECTION_DIALOG (colorseldiag)->colorsel;
-  gtk_color_selection_get_current_color (GTK_COLOR_SELECTION (colorsel),
-					 &gdk_color);
-
-  /* Since we are only going to save 24bit precision, we might as well
-   * make sure we don't display any more than that */
-  gdk_color.red = (gdk_color.red >> 8) << 8;
-  gdk_color.green = (gdk_color.green >> 8) << 8;
-  gdk_color.blue = (gdk_color.blue >> 8) << 8;
+  colorsel = gtk_color_selection_dialog_get_color_selection(
+		  GTK_COLOR_SELECTION_DIALOG(colorseldiag));
+  gtk_color_selection_get_current_rgba(GTK_COLOR_SELECTION(colorsel),
+					 &color);
 
   /* fill data */
   if (isadd)
-    gtk_list_store_set (ep.gs, &it, 0, COLSPACES, 1, &gdk_color, 2, "", -1);
+    gtk_list_store_set (ep.gs, &it, 0, COLSPACES, 1, &color, 2, "", -1);
   else
-    gtk_list_store_set (ep.gs, &it, 0, COLSPACES, 1, &gdk_color, -1);
+    gtk_list_store_set (ep.gs, &it, 0, COLSPACES, 1, &color, -1);
 
   gtk_widget_hide (colorseldiag);
 
@@ -724,7 +691,7 @@ void
 on_protocol_edit_button_clicked (GtkButton * button, gpointer user_data)
 {
   GtkWidget *protocol_edit_dialog = NULL;
-  protocol_edit_dialog = glade_xml_get_widget (appdata.xml, "protocol_edit_dialog");
+  protocol_edit_dialog = GTK_WIDGET(gtk_builder_get_object(appdata.xml, "protocol_edit_dialog"));
   gtk_widget_show (protocol_edit_dialog);
 }				/* on_protocol_edit_button_clicked */
 
@@ -735,7 +702,7 @@ on_protocol_edit_dialog_show (GtkWidget * wdg, gpointer user_data)
   GtkTreePath *gpath = NULL;
   GtkTreeViewColumn *gcol = NULL;
   GtkTreeIter it;
-  GtkComboBoxEntry *cbox;
+  GtkComboBox *cbox;
   EATreePos ep;
 
   if (!get_color_store (&ep))
@@ -751,7 +718,7 @@ on_protocol_edit_dialog_show (GtkWidget * wdg, gpointer user_data)
 
   gtk_tree_model_get (GTK_TREE_MODEL (ep.gs), &it, 2, &protocol_string, -1);
 
-  cbox = GTK_COMBO_BOX_ENTRY(glade_xml_get_widget (appdata.xml, "protocol_entry"));
+  cbox = GTK_COMBO_BOX(gtk_builder_get_object (appdata.xml, "protocol_entry"));
   cbox_add_select(cbox, protocol_string);
 
   g_free (protocol_string);
@@ -761,11 +728,12 @@ on_protocol_edit_dialog_show (GtkWidget * wdg, gpointer user_data)
 void
 on_protocol_edit_ok_clicked (GtkButton * button, gpointer user_data)
 {
+  const gchar *combo_string;
   gchar *proto_string;
   GtkTreePath *gpath = NULL;
   GtkTreeViewColumn *gcol = NULL;
   GtkTreeIter it;
-  GtkComboBoxEntry *cbox;
+  GtkComboBox *cbox;
   EATreePos ep;
   if (!get_color_store (&ep))
     return;
@@ -775,19 +743,19 @@ on_protocol_edit_ok_clicked (GtkButton * button, gpointer user_data)
   if (!gpath)
     return;			/* no row selected */
 
-  if (!gtk_tree_model_get_iter (GTK_TREE_MODEL (ep.gs), &it, gpath))
+  if (!gtk_tree_model_get_iter(GTK_TREE_MODEL (ep.gs), &it, gpath))
     return;			/* path not found */
 
-  cbox = GTK_COMBO_BOX_ENTRY(glade_xml_get_widget (appdata.xml, "protocol_entry"));
-  proto_string = gtk_combo_box_get_active_text(GTK_COMBO_BOX(cbox));
-  proto_string = g_utf8_strup (proto_string, -1);
+  cbox = GTK_COMBO_BOX(gtk_builder_get_object (appdata.xml, "protocol_entry"));
+  combo_string = gtk_entry_get_text(GTK_ENTRY(gtk_bin_get_child(GTK_BIN(cbox))));
+  proto_string = g_utf8_strup(g_strdup(combo_string), -1);
   proto_string = remove_spaces(proto_string);
-  
+
   cbox_add_select(cbox, proto_string);
   gtk_list_store_set (ep.gs, &it, 2, proto_string, -1);
 
   g_free (proto_string);
-  gtk_widget_hide (glade_xml_get_widget (appdata.xml, "protocol_edit_dialog"));
+  gtk_widget_hide(GTK_WIDGET(gtk_builder_get_object(appdata.xml, "protocol_edit_dialog")));
 
   colors_changed = TRUE;
   color_list_to_pref ();
@@ -808,7 +776,7 @@ pref_to_color_list (void)
 
   for (i = 0; pref.colors[i]; ++i)
     {
-      GdkColor gdk_color;
+      GdkRGBA color;
       gchar **colors_protocols = NULL;
       gchar *protocol = NULL;
       GtkTreeIter it;
@@ -816,17 +784,17 @@ pref_to_color_list (void)
       colors_protocols = g_strsplit (pref.colors[i], ";", 0);
 
       /* converting color */
-      gdk_color_parse (colors_protocols[0], &gdk_color);
-      
+      gdk_rgba_parse(&color, colors_protocols[0]);
+
       /* converting proto name */
       if (!colors_protocols[1])
-	protocol = "";
+        protocol = "";
       else
-	protocol = colors_protocols[1];
+        protocol = colors_protocols[1];
 
       /* adds a new row */
       gtk_list_store_append (ep.gs, &it);
-      gtk_list_store_set (ep.gs, &it, 0, COLSPACES, 1, &gdk_color, 
+      gtk_list_store_set (ep.gs, &it, 0, COLSPACES, 1, &color,
                           2, protocol, -1);
       g_strfreev(colors_protocols);
     }
@@ -856,30 +824,30 @@ color_list_to_pref (void)
   for (i = 0; i < ncolors; i++)
     {
       gchar *protocol;
-      GdkColor *gdk_color;
+      GdkRGBA *color;
 
       /* reads the list */
       gtk_tree_model_get (GTK_TREE_MODEL (ep.gs), &it,
-                          1, &gdk_color, 2, &protocol, -1);
+                          1, &color, 2, &protocol, -1);
 
-      pref.colors[i] = g_strdup_printf ("#%02x%02x%02x;%s", 
-                                        gdk_color->red >> 8, 
-                                        gdk_color->green >> 8, 
-                                        gdk_color->blue >> 8,
+      pref.colors[i] = g_strdup_printf ("#%02x%02x%02x;%s",
+                                        (unsigned int)(color->red * 255),
+                                        (unsigned int)(color->green * 255),
+                                        (unsigned int)(color->blue * 255),
                                         protocol);
       g_free (protocol);
 
       gtk_tree_model_iter_next (GTK_TREE_MODEL (ep.gs), &it);
     }
   pref.colors[ncolors] = NULL;
-  
+
   pref.colors = protohash_compact(pref.colors);
   protohash_read_prefvect(pref.colors);
 }
 
 /* adds a string to the combo if not already present and loads it in the
    edit box. If str is "" simply clears the edit box */
-static void cbox_add_select(GtkComboBoxEntry *cbox, const gchar *str)
+static void cbox_add_select(GtkComboBox *cbox, const gchar *str)
 {
   GtkTreeModel *model;
   GtkTreeIter iter,iter3;
@@ -889,7 +857,7 @@ static void cbox_add_select(GtkComboBoxEntry *cbox, const gchar *str)
 
   if (!str)
      str = "";
-  
+
   entry = gtk_bin_get_child (GTK_BIN (cbox));
   gtk_entry_set_text (GTK_ENTRY (entry), str);
 
@@ -905,12 +873,12 @@ static void cbox_add_select(GtkComboBoxEntry *cbox, const gchar *str)
             {
               /* already present */
               g_free(modelstr);
-              return; 
+              return;
             }
           g_free(modelstr);
         }
 
-      gtk_list_store_insert_with_values(GTK_LIST_STORE(model), 
+      gtk_list_store_insert_with_values(GTK_LIST_STORE(model),
                                         &iter3, 0, 0, str, -1);
     }
 }
@@ -918,6 +886,5 @@ static void cbox_add_select(GtkComboBoxEntry *cbox, const gchar *str)
 void change_refresh_period(guint32 newperiod)
 {
   pref.refresh_period = newperiod;
-  timeout_changed();
+  diagram_timeout_changed();
 }
-
